soapcw package
==============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   soapcw.cnn
   soapcw.cw
   soapcw.line_aware_stat
   soapcw.tools

Submodules
----------

soapcw.cli module
-----------------

.. automodule:: soapcw.cli
   :members:
   :undoc-members:
   :show-inheritance:

soapcw.soapcw module
--------------------

.. automodule:: soapcw.soapcw
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: soapcw
   :members:
   :undoc-members:
   :show-inheritance:
